ModelArts Service
=================

ModelArts is a one-stop development platform for AI developers.
With distributed training, automated model building, and model
deployment, ModelArts helps AI developers quickly build models
and efficiently manage the AI development lifecycle.

.. contents:: Table of Contents
   :local:

Devenv Instance
---------------

List Devenv Instances
^^^^^^^^^^^^^^^^^^^^^

This interface is used to query devenv instances list.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/list_devenv_instances.py
   :lines: 15-21

Create Devenv Instance
^^^^^^^^^^^^^^^^^^^^^^

This interface is used to create a devenv instance with
parameters.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/create_devenv_instance.py
   :lines: 15-35

Get Devenv Instance
^^^^^^^^^^^^^^^^^^^

This interface is used to get a devenv instance by ID
or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/get_devenv_instance.py
   :lines: 15-22

Find Devenv Instance
^^^^^^^^^^^^^^^^^^^^

This interface is used to find a devenv instance by id or name.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/find_devenv_instance.py
   :lines: 15-24

Start Devenv Instance
^^^^^^^^^^^^^^^^^^^^^

This interface is used to start a devenv instance by
id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/start_devenv_instance.py
   :lines: 15-22

Stop Devenv Instance
^^^^^^^^^^^^^^^^^^^^

This interface is used to stop a devenv instance by
id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/stop_devenv_instance.py
   :lines: 15-22

Delete Devenv Instance
^^^^^^^^^^^^^^^^^^^^^^

This interface is used to delete a devenv instance by ID
or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.devenv.Devenv`.

.. literalinclude:: ../examples/modelartsv1/delete_devenv_instance.py
   :lines: 15-21


ModelArts Service
-----------------

List Services
^^^^^^^^^^^^^

This interface is used to query modelarts services list.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/list_services.py
   :lines: 15-21

Create Service
^^^^^^^^^^^^^^

This interface is used to create a modelarts service with
parameters.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/create_service.py
   :lines: 15-45

Get Service
^^^^^^^^^^^

This interface is used to get a service by ID or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/get_service.py
   :lines: 15-22

Find Service
^^^^^^^^^^^^

This interface is used to find a service by Id or name.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/find_service.py
   :lines: 15-22

Start Service
^^^^^^^^^^^^^

This interface is used to start a Service by Id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/start_service.py
   :lines: 15-24

Stop Service
^^^^^^^^^^^^

This interface is used to stop a service by Id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/stop_service.py
   :lines: 15-24

Delete Service
^^^^^^^^^^^^^^

This interface is used to delete a service by Id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.service.Service`.

.. literalinclude:: ../examples/modelartsv1/delete_service.py
   :lines: 15-23


ModelArts Model
-----------------

List Models
^^^^^^^^^^^

This interface is used to query models list.
:class:`~otcextensions.sdk.modelartsv1.v1.model.Model`.

.. literalinclude:: ../examples/modelartsv1/list_models.py
   :lines: 15-21

Create Model
^^^^^^^^^^^^

This interface is used to create a model with parameters.
:class:`~otcextensions.sdk.modelartsv1.v1.model.Model`.

.. literalinclude:: ../examples/modelartsv1/create_model.py
   :lines: 15-85

Get Model
^^^^^^^^^

This interface is used to get a model by ID or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.model.Model`.

.. literalinclude:: ../examples/modelartsv1/get_model.py
   :lines: 15-22

Find Model
^^^^^^^^^^

This interface is used to find a model by Id or name.
:class:`~otcextensions.sdk.modelartsv1.v1.model.Model`.

.. literalinclude:: ../examples/modelartsv1/find_model.py
   :lines: 15-22

Delete Model
^^^^^^^^^^^^

This interface is used to delete a model by Id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.model.Model`.

.. literalinclude:: ../examples/modelartsv1/delete_model.py
   :lines: 15-23


ModelArts Training Job
----------------------

List Training Jobs
^^^^^^^^^^^^^^^^^^

This interface is used to query training jobs list.
:class:`~otcextensions.sdk.modelartsv1.v1.training_job.TrainingJob`.

.. literalinclude:: ../examples/modelartsv1/list_training_jobs.py
   :lines: 15-21

Create Training Job
^^^^^^^^^^^^^^^^^^^

This interface is used to create a training job with parameters.
:class:`~otcextensions.sdk.modelartsv1.v1.training_job.TrainingJob`.

.. literalinclude:: ../examples/modelartsv1/create_training_job.py
   :lines: 15-48

Delete Training Job
^^^^^^^^^^^^^^^^^^^

This interface is used to delete a training job by Id or an instance of class.
:class:`~otcextensions.sdk.modelartsv1.v1.training_job.TrainingJob`.

.. literalinclude:: ../examples/modelartsv1/delete_training_job.py
   :lines: 15-22
